Contributors
===================

## Core Developers
- Sambhav Kothari ([@samj1912](https://github.com/samj1912))
- Timothy Crosley ([@timothycrosley](https://github.com/timothycrosley))

## Special Mentions
- Peter Olson ([@peter200lx](https://github.com/peter200lx)) for coming up with the main implementation idea behind cruft.

## Notable Bug Reporters
-

## Code Contributors
- Peter Olson ([@peter200lx](https://github.com/peter200lx))
- Medhat Assaad ([@massaad](https://github.com/massaad))
- Appunni M ([@appunni-dishq](https://github.com/appunni-dishq))
- Gilbert Gilb's ([@gilbsgilbs](https://github.com/gilbsgilbs))

## Documenters
-


--------------------------------------------

A sincere thanks to everyone who helps make cruft into a great Python3 project!

~Timothy Crosley
